pychemia.code.dftb.task package
===============================

.. automodule:: pychemia.code.dftb.task
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.code.dftb.task.kpconv module
-------------------------------------

.. automodule:: pychemia.code.dftb.task.kpconv
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.dftb.task.relax module
------------------------------------

.. automodule:: pychemia.code.dftb.task.relax
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.dftb.task.static module
-------------------------------------

.. automodule:: pychemia.code.dftb.task.static
    :members:
    :undoc-members:
    :show-inheritance:


